.. _cutouts:

Cutouts
=======

Everything related to cutouts is documented bellow:

.. currentmodule:: hostphot.cutouts
.. autofunction:: query_ps1
.. autofunction:: get_PS1_urls
.. autofunction:: get_PS1_images
.. autofunction:: get_DES_urls
.. autofunction:: get_DES_images
.. autofunction:: get_SDSS_images
.. autofunction:: download_multiband_images

